(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('rxjs/operators'), require('@angular/common'), require('@angular/common/http')) :
    typeof define === 'function' && define.amd ? define('ngx-httpclient-busy', ['exports', '@angular/core', 'rxjs', 'rxjs/operators', '@angular/common', '@angular/common/http'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngx-httpclient-busy'] = {}, global.ng.core, global.rxjs, global.rxjs.operators, global.ng.common, global.ng.common.http));
}(this, (function (exports, i0, rxjs, operators, common, http) { 'use strict';

    var CounterService = /** @class */ (function () {
        function CounterService() {
            var _this = this;
            this._connectionCounter = 0;
            this._observable = new rxjs.Observable(function (subscriber) {
                _this._subscriber = subscriber;
            }).pipe(operators.share());
        }
        Object.defineProperty(CounterService.prototype, "observable", {
            get: function () {
                return this._observable;
            },
            enumerable: false,
            configurable: true
        });
        CounterService.prototype.increment = function () {
            this._connectionCounter += 1;
            this._next();
        };
        CounterService.prototype.decrement = function () {
            this._connectionCounter -= 1;
            this._next();
        };
        CounterService.prototype._next = function () {
            if (this._subscriber) {
                this._subscriber.next(this._connectionCounter);
            }
        };
        return CounterService;
    }());
    CounterService.ɵprov = i0.ɵɵdefineInjectable({ factory: function CounterService_Factory() { return new CounterService(); }, token: CounterService, providedIn: "root" });
    CounterService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root',
                },] }
    ];
    CounterService.ctorParameters = function () { return []; };

    var HttpClientBusyDirective = /** @class */ (function () {
        function HttpClientBusyDirective(el, renderer, counter) {
            this.el = el;
            this.renderer = renderer;
            this.counter = counter;
            this.httpClientBusyConfig = {};
        }
        HttpClientBusyDirective.prototype._updateStatus = function (count) {
            var busy = count > 0;
            var hasIdle = this.el.nativeElement.classList.contains(this.httpClientBusyConfig.idle);
            var hasBusy = this.el.nativeElement.classList.contains(this.httpClientBusyConfig.busy);
            if (busy) {
                if (this.httpClientBusyConfig.idle && hasIdle) {
                    this.renderer.removeClass(this.el.nativeElement, this.httpClientBusyConfig.idle);
                }
                if (this.httpClientBusyConfig.busy && !hasBusy) {
                    this.renderer.addClass(this.el.nativeElement, this.httpClientBusyConfig.busy);
                }
            }
            else {
                if (this.httpClientBusyConfig.busy && hasBusy) {
                    this.renderer.removeClass(this.el.nativeElement, this.httpClientBusyConfig.busy);
                }
                if (this.httpClientBusyConfig.idle && !hasIdle) {
                    this.renderer.addClass(this.el.nativeElement, this.httpClientBusyConfig.idle);
                }
            }
        };
        HttpClientBusyDirective.prototype.ngOnInit = function () {
            var _this = this;
            this.httpClientBusyConfig.idle = this.httpClientBusy.idle || 'fade';
            this.httpClientBusyConfig.busy = this.httpClientBusy.busy || '';
            this._updateStatus(0);
            this.autoUnsubscribe = this.counter.observable.subscribe(function (next) { return _this._updateStatus(next); });
        };
        HttpClientBusyDirective.prototype.ngOnDestroy = function () {
            this.autoUnsubscribe.unsubscribe();
        };
        return HttpClientBusyDirective;
    }());
    HttpClientBusyDirective.decorators = [
        { type: i0.Directive, args: [{
                    selector: '[httpClientBusy]',
                },] }
    ];
    HttpClientBusyDirective.ctorParameters = function () { return [
        { type: i0.ElementRef },
        { type: i0.Renderer2 },
        { type: CounterService }
    ]; };
    HttpClientBusyDirective.propDecorators = {
        httpClientBusy: [{ type: i0.Input }]
    };

    var HttpClientBusyInterceptor = /** @class */ (function () {
        function HttpClientBusyInterceptor(counter) {
            this.counter = counter;
        }
        HttpClientBusyInterceptor.prototype.intercept = function (req, next) {
            var _this = this;
            this.counter.increment();
            return next.handle(req).pipe(operators.tap(function (evt) {
                if (evt instanceof http.HttpResponse) {
                    _this.counter.decrement();
                }
            }), operators.catchError(function (err) {
                if (err instanceof http.HttpErrorResponse) {
                    _this.counter.decrement();
                }
                return rxjs.throwError(err);
            }));
        };
        return HttpClientBusyInterceptor;
    }());
    HttpClientBusyInterceptor.ɵprov = i0.ɵɵdefineInjectable({ factory: function HttpClientBusyInterceptor_Factory() { return new HttpClientBusyInterceptor(i0.ɵɵinject(CounterService)); }, token: HttpClientBusyInterceptor, providedIn: "root" });
    HttpClientBusyInterceptor.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root',
                },] }
    ];
    HttpClientBusyInterceptor.ctorParameters = function () { return [
        { type: CounterService }
    ]; };

    var HttpClientBusyModule = /** @class */ (function () {
        function HttpClientBusyModule() {
        }
        HttpClientBusyModule.forRoot = function () {
            return {
                ngModule: HttpClientBusyModule,
            };
        };
        return HttpClientBusyModule;
    }());
    HttpClientBusyModule.decorators = [
        { type: i0.NgModule, args: [{
                    imports: [common.CommonModule, http.HttpClientModule],
                    declarations: [HttpClientBusyDirective],
                    exports: [HttpClientBusyDirective],
                    providers: [{ provide: http.HTTP_INTERCEPTORS, useClass: HttpClientBusyInterceptor, multi: true }],
                },] }
    ];

    /*
     * Public API Surface of ngx-httpclient-busy
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.CounterService = CounterService;
    exports.HttpClientBusyDirective = HttpClientBusyDirective;
    exports.HttpClientBusyModule = HttpClientBusyModule;
    exports.ɵa = HttpClientBusyInterceptor;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-httpclient-busy.umd.js.map
